@@ -36,6 +36,7 @@ class QWebEngineDownloadItem;
 class QWinTaskbarButton;
 
 class DownloadItem;
+class DownloadManagerModel;
 class WebPage;
 
 class FALKON_EXPORT DownloadManager : public QWidget
@@ -82,12 +83,14 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     void clearList();
-    void deleteItem(DownloadItem* item);
     void downloadFinished(bool success);
 
 Q_SIGNALS:
     void resized(QSize);
     void downloadsCountChanged();
+    void downloadAdded(DownloadItem *item);
+    void downloadRemoved(DownloadItem *item);
+    void downloadFinished();
 
 private:
     void timerEvent(QTimerEvent* e) override;
@@ -99,6 +102,7 @@ private:
     QWinTaskbarButton *taskbarButton();
 
     Ui::DownloadManager* ui;
+    DownloadManagerModel *m_model;
     QBasicTimer m_timer;
 
     QString m_lastDownloadPath;
